[−][src]Struct anpp::Decoder
Decoder for the Advanced Navigation Packet Protocol.
Implementations
impl Decoder[src]
pub const DEFAULT_DECODER_BUFFER_SIZE: usize[src]
The buffer size used when not compiled with the std feature flag.
pub fn new() -> Decoder[src]
Create a new Decoder.
pub fn bytes_in_buffer(&self) -> usize[src]
How many bytes are in the Decoder's internal buffer?
pub fn remaining_capacity(&self) -> usize[src]
The amount of data that can be added to the Decoder's internal buffer
before it will become full.
Note
When compiled with the std feature the buffer is considered
effectively infinite.
pub fn clear(&mut self)[src]
Clear the Decoder's internal buffer.
pub fn push_data(&mut self, data: &[u8]) -> Result<(), InsufficientCapacity>[src]
Try to add some more raw data to the Decoder's internal buffer.
pub fn decode(&mut self) -> Result<Packet, DecodeError>[src]
Retrieve the next Packet from the Decoder's internal buffer.